from distutils.core import setup

setup(
        name = 'ybEmail',
        version = '1.0.0',
        py_modules = ['ybEmail'],
        author = 'AlienDev',
        author_email = 'yb@aliendev.com',
        url = 'http://www.aliendev.com',
        description = 'This is a module made to send emails from python programs easier.',
    )
